@@ -1,14 +1,7 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import
-
 import logging
-import os
 
-from distutils.version import LooseVersion
-from django import get_version
 from django.db import models
-from django.utils import six
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from .. import settings as filer_settings
 from ..utils.compatibility import PILImage
@@ -16,9 +9,8 @@ from ..utils.filer_easy_thumbnails import FilerThumbnailer
 from ..utils.pil_exif import get_exif_for_file
 from .filemodels import File
 
-logger = logging.getLogger(__name__)
 
-DJANGO_GTE_17 = LooseVersion(get_version()) >= LooseVersion('1.7.0')
+logger = logging.getLogger(__name__)
 
 
 class BaseImage(File):
@@ -26,7 +18,7 @@ class BaseImage(File):
     DEFAULT_THUMBNAILS = {
         'admin_clipboard_icon': {'size': (32, 32), 'crop': True,
                                  'upscale': True},
-        'admin_sidebar_preview': {'size': (SIDEBAR_IMAGE_WIDTH, 10000), 'upscale': True},
+        'admin_sidebar_preview': {'size': (SIDEBAR_IMAGE_WIDTH, 0), 'upscale': True},
         'admin_directory_listing_icon': {'size': (48, 48),
                                          'crop': True, 'upscale': True},
         'admin_tiny_icon': {'size': (32, 32), 'crop': True, 'upscale': True},
@@ -42,30 +34,40 @@ class BaseImage(File):
 
     subject_location = models.CharField(_('subject location'), max_length=64, blank=True,
                                         default='')
-    if DJANGO_GTE_17:
-        file_ptr = models.OneToOneField(to='filer.File', related_name='%(app_label)s_%(class)s_file',
-                                        on_delete=models.CASCADE)
+    file_ptr = models.OneToOneField(
+        to='filer.File', parent_link=True,
+        related_name='%(app_label)s_%(class)s_file',
+        on_delete=models.CASCADE,
+    )
 
     @classmethod
-    def matches_file_type(cls, iname, ifile, request):
-        # This was originally in admin/clipboardadmin.py  it was inside of a try
-        # except, I have moved it here outside of a try except because I can't
-        # figure out just what kind of exception this could generate... all it was
-        # doing for me was obscuring errors...
-        # --Dave Butler <croepha@gmail.com>
-        iext = os.path.splitext(iname)[1].lower()
-        return iext in ['.jpg', '.jpeg', '.png', '.gif']
+    def matches_file_type(cls, iname, ifile, mime_type):
+        # source: https://www.freeformatter.com/mime-types-list.html
+        image_subtypes = ['gif', 'jpeg', 'png', 'x-png']
+        maintype, subtype = mime_type.split('/')
+        return maintype == 'image' and subtype in image_subtypes
+
+    def file_data_changed(self, post_init=False):
+        attrs_updated = super().file_data_changed(post_init=post_init)
+        if attrs_updated:
+            try:
+                try:
+                    imgfile = self.file.file
+                except ValueError:
+                    imgfile = self.file_ptr.file
+                imgfile.seek(0)
+                self._width, self._height = PILImage.open(imgfile).size
+                imgfile.seek(0)
+            except Exception:
+                if post_init is False:
+                    # in case `imgfile` could not be found, unset dimensions
+                    # but only if not initialized by loading a fixture file
+                    self._width, self._height = None, None
+        return attrs_updated
 
     def save(self, *args, **kwargs):
         self.has_all_mandatory_data = self._check_validity()
-        try:
-            # do this more efficient somehow?
-            self.file.seek(0)
-            self._width, self._height = PILImage.open(self.file).size
-        except Exception:
-            # probably the image is missing. nevermind.
-            pass
-        super(BaseImage, self).save(*args, **kwargs)
+        super().save(*args, **kwargs)
 
     def _check_validity(self):
         if not self.name:
@@ -104,7 +106,7 @@ class BaseImage(File):
         image. Return the string 'ALL' if the user has all rights.
         """
         user = request.user
-        if not user.is_authenticated():
+        if not user.is_authenticated:
             return False
         elif user.is_superuser:
             return True
@@ -132,7 +134,7 @@ class BaseImage(File):
 
     def _generate_thumbnails(self, required_thumbnails):
         _thumbnails = {}
-        for name, opts in six.iteritems(required_thumbnails):
+        for name, opts in required_thumbnails.items():
             try:
                 opts.update({'subject_location': self.subject_location})
                 thumb = self.file.get_thumbnail(opts)
@@ -170,8 +172,9 @@ class BaseImage(File):
             thumbnail_basedir=self.file.thumbnail_basedir)
         return tn
 
-    class Meta(object):
+    class Meta:
         app_label = 'filer'
         verbose_name = _('image')
         verbose_name_plural = _('images')
         abstract = True
+        default_manager_name = 'objects'
