@@ -1,13 +1,9 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import
-
-from django.contrib.staticfiles.templatetags.staticfiles import static
+from django.templatetags.static import static
 
 from ..settings import FILER_ADMIN_ICON_SIZES
 
 
-class IconsMixin(object):
+class IconsMixin:
     """
     Can be used on any model that has a _icon attribute. will return a dict
     containing urls for icons of different sizes with that name.
