@@ -1,12 +1,7 @@
-from __future__ import absolute_import, unicode_literals
-
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
-
-from ..utils.compatibility import python_2_unicode_compatible
+from django.utils.translation import gettext_lazy as _
 
 
-@python_2_unicode_compatible
 class ThumbnailOption(models.Model):
     """
     This class defines the option use to create the thumbnail.
