@@ -1,13 +1,13 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, unicode_literals
-
 from django.template import Library
 from django.utils.html import format_html_join
 
 from ..admin.tools import admin_url_params, admin_url_params_encoded
 
+
 register = Library()
 
+assignment_tag = getattr(register, 'assignment_tag', register.simple_tag)
+
 
 def filer_actions(context):
     """
@@ -16,6 +16,8 @@ def filer_actions(context):
     """
     context['action_index'] = context.get('action_index', -1) + 1
     return context
+
+
 filer_actions = register.inclusion_tag(
     "admin/filer/actions.html", takes_context=True)(filer_actions)
 
@@ -34,3 +36,20 @@ def filer_admin_context_hidden_formfields(context):
         '<input type="hidden" name="{0}" value="{1}">',
         admin_url_params(request).items(),
     )
+
+
+@assignment_tag(takes_context=True)
+def filer_has_permission(context, item, action):
+    """Does the current user (taken from the request in the context) have
+    permission to do the given action on the given item.
+
+    """
+    permission_method_name = 'has_{action}_permission'.format(action=action)
+    permission_method = getattr(item, permission_method_name, None)
+    request = context.get('request')
+
+    if not permission_method or not request:
+        return False
+    # Call the permission method.
+    # This amounts to calling `item.has_X_permission(request)`
+    return permission_method(request)
