@@ -1,19 +1,16 @@
-from __future__ import unicode_literals
-
-try:
-    from django.utils.encoding import force_text
-except ImportError:
-    # Django < 1.5
-    from django.utils.encoding import force_unicode as force_text
-from django.utils.timezone import now
-from filer.utils.files import get_valid_filename
 import os
 
+from django.utils.encoding import force_text
+from django.utils.timezone import now
+
+from .files import get_valid_filename
+
 
 def by_date(instance, filename):
     datepart = force_text(now().strftime("%Y/%m/%d"))
     return os.path.join(datepart, get_valid_filename(filename))
 
+
 def randomized(instance, filename):
     import uuid
     uuid_str = str(uuid.uuid4())
@@ -21,7 +18,7 @@ def randomized(instance, filename):
             get_valid_filename(filename))
 
 
-class prefixed_factory(object):
+class prefixed_factory:
     def __init__(self, upload_to, prefix):
         self.upload_to = upload_to
         self.prefix = prefix
